{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Bisulfite alignment and QC",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/QCannotation"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#main/assay_non_cpg_sites/true",
                            "#main/assay_non_cpg_sites/false"
                        ]
                    },
                    "default": "false",
                    "doc": "Variable to determine if user wants to obtain obtain bed/bigwig files for non-CpG cytosines. Value - true or false",
                    "id": "#main/assay_non_cpg_sites"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/instrument_data_bams"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/read_group_id"
                },
                {
                    "type": "string",
                    "id": "#main/reference_index"
                },
                {
                    "type": "File",
                    "id": "#main/reference_sizes"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": "int",
                    "id": "#main/trimming_adapter_min_overlap"
                },
                {
                    "type": "string",
                    "id": "#main/trimming_adapter_trim_end"
                },
                {
                    "type": "File",
                    "id": "#main/trimming_adapters"
                },
                {
                    "type": "int",
                    "id": "#main/trimming_max_uncalled"
                },
                {
                    "type": "int",
                    "id": "#main/trimming_min_readlength"
                }
            ],
            "steps": [
                {
                    "run": "#bam_to_cram.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged_bam",
                            "id": "#main/bam_to_cram/bam"
                        },
                        {
                            "source": "#main/reference_index",
                            "id": "#main/bam_to_cram/reference"
                        }
                    ],
                    "out": [
                        "#main/bam_to_cram/cram"
                    ],
                    "id": "#main/bam_to_cram"
                },
                {
                    "run": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl",
                    "scatter": [
                        "#main/bam_to_trimmed_fastq_and_biscuit_alignments/bam",
                        "#main/bam_to_trimmed_fastq_and_biscuit_alignments/read_group_id"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/trimming_adapter_min_overlap",
                            "id": "#main/bam_to_trimmed_fastq_and_biscuit_alignments/adapter_min_overlap"
                        },
                        {
                            "source": "#main/trimming_adapter_trim_end",
                            "id": "#main/bam_to_trimmed_fastq_and_biscuit_alignments/adapter_trim_end"
                        },
                        {
                            "source": "#main/trimming_adapters",
                            "id": "#main/bam_to_trimmed_fastq_and_biscuit_alignments/adapters"
                        },
                        {
                            "source": "#main/instrument_data_bams",
                            "id": "#main/bam_to_trimmed_fastq_and_biscuit_alignments/bam"
                        },
                        {
                            "source": "#main/trimming_max_uncalled",
                            "id": "#main/bam_to_trimmed_fastq_and_biscuit_alignments/max_uncalled"
                        },
                        {
                            "source": "#main/trimming_min_readlength",
                            "id": "#main/bam_to_trimmed_fastq_and_biscuit_alignments/min_readlength"
                        },
                        {
                            "source": "#main/read_group_id",
                            "id": "#main/bam_to_trimmed_fastq_and_biscuit_alignments/read_group_id"
                        },
                        {
                            "source": "#main/reference_index",
                            "id": "#main/bam_to_trimmed_fastq_and_biscuit_alignments/reference_index"
                        }
                    ],
                    "out": [
                        "#main/bam_to_trimmed_fastq_and_biscuit_alignments/aligned_bam"
                    ],
                    "id": "#main/bam_to_trimmed_fastq_and_biscuit_alignments"
                },
                {
                    "run": "#bedgraph_to_bigwig.cwl",
                    "in": [
                        {
                            "source": "#main/vcf2bed/methylation_bedgraph",
                            "id": "#main/bedgraph_to_bigwig/methylation_bedgraph"
                        },
                        {
                            "source": "#main/reference_sizes",
                            "id": "#main/bedgraph_to_bigwig/reference_sizes"
                        }
                    ],
                    "out": [
                        "#main/bedgraph_to_bigwig/methylation_bigwig"
                    ],
                    "id": "#main/bedgraph_to_bigwig"
                },
                {
                    "run": "#bisulfite_qc.cwl",
                    "in": [
                        {
                            "source": "#main/QCannotation",
                            "id": "#main/bisulfite_qc/QCannotation"
                        },
                        {
                            "source": "#main/merge/merged_bam",
                            "id": "#main/bisulfite_qc/bam"
                        },
                        {
                            "source": "#main/reference_index",
                            "id": "#main/bisulfite_qc/reference"
                        },
                        {
                            "source": "#main/pileup/vcf",
                            "id": "#main/bisulfite_qc/vcf"
                        }
                    ],
                    "out": [
                        "#main/bisulfite_qc/QC_directory"
                    ],
                    "id": "#main/bisulfite_qc"
                },
                {
                    "run": "#index_cram.cwl",
                    "in": [
                        {
                            "source": "#main/bam_to_cram/cram",
                            "id": "#main/index_cram/cram"
                        }
                    ],
                    "out": [
                        "#main/index_cram/indexed_cram"
                    ],
                    "id": "#main/index_cram"
                },
                {
                    "run": "#merge_bams.cwl",
                    "in": [
                        {
                            "source": "#main/bam_to_trimmed_fastq_and_biscuit_alignments/aligned_bam",
                            "id": "#main/merge/bams"
                        }
                    ],
                    "out": [
                        "#main/merge/merged_bam"
                    ],
                    "id": "#main/merge"
                },
                {
                    "run": "#biscuit_pileup.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged_bam",
                            "id": "#main/pileup/bam"
                        },
                        {
                            "source": "#main/reference_index",
                            "id": "#main/pileup/reference"
                        }
                    ],
                    "out": [
                        "#main/pileup/vcf"
                    ],
                    "id": "#main/pileup"
                },
                {
                    "run": "#bisulfite_vcf2bed.cwl",
                    "in": [
                        {
                            "source": "#main/assay_non_cpg_sites",
                            "id": "#main/vcf2bed/assay_non_cpg_sites"
                        },
                        {
                            "source": "#main/reference_index",
                            "id": "#main/vcf2bed/reference"
                        },
                        {
                            "source": "#main/pileup/vcf",
                            "id": "#main/vcf2bed/vcf"
                        }
                    ],
                    "out": [
                        "#main/vcf2bed/methylation_bed",
                        "#main/vcf2bed/methylation_bedgraph"
                    ],
                    "id": "#main/vcf2bed"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bedgraph_to_bigwig/methylation_bigwig",
                    "id": "#main/cpg_bigwig"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/vcf2bed/methylation_bed",
                    "id": "#main/cpgs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/index_cram/indexed_cram",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#main/cram"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/bisulfite_qc/QC_directory",
                    "id": "#main/gathered_directory"
                },
                {
                    "type": "File",
                    "outputSource": "#main/pileup/vcf",
                    "id": "#main/vcf"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "bam to trimmed fastqs and biscuit alignments",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/adapter_trim_end"
                },
                {
                    "type": "File",
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/adapters"
                },
                {
                    "type": "File",
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/bam"
                },
                {
                    "type": "int",
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/max_uncalled"
                },
                {
                    "type": "int",
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/min_readlength"
                },
                {
                    "type": "string",
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/read_group_id"
                },
                {
                    "type": "string",
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/reference_index"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_markdup/markdup_bam",
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/aligned_bam"
                }
            ],
            "steps": [
                {
                    "run": "#bam_to_fastq.cwl",
                    "in": [
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/bam",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/bam_to_fastq/bam"
                        }
                    ],
                    "out": [
                        "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/bam_to_fastq/fastq1",
                        "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/bam_to_fastq/fastq2"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/bam_to_fastq"
                },
                {
                    "run": "#biscuit_align.cwl",
                    "in": [
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/fastq1",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_align/fastq1"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/fastq2",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_align/fastq2"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/read_group_id",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_align/read_group_id"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/reference_index",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_align/reference_index"
                        }
                    ],
                    "out": [
                        "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_align/aligned_bam"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_align"
                },
                {
                    "run": "#biscuit_markdup.cwl",
                    "in": [
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/index_bam/indexed_bam",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_markdup/bam"
                        }
                    ],
                    "out": [
                        "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_markdup/markdup_bam"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_markdup"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/biscuit_align/aligned_bam",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/index_bam"
                },
                {
                    "run": "#trim_fastq.cwl",
                    "in": [
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/adapter_min_overlap",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/adapter_min_overlap"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/adapter_trim_end",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/adapter_trim_end"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/adapters",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/adapters"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/max_uncalled",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/max_uncalled"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/min_readlength",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/min_readlength"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/bam_to_fastq/fastq1",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/reads1"
                        },
                        {
                            "source": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/bam_to_fastq/fastq2",
                            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/reads2"
                        }
                    ],
                    "out": [
                        "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/fastq1",
                        "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq/fastq2"
                    ],
                    "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl/trim_fastq"
                }
            ],
            "id": "#bam_to_trimmed_fastq_and_biscuit_alignments.cwl"
        },
        {
            "class": "Workflow",
            "label": "Bisulfite QC tools",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#bisulfite_qc.cwl/QCannotation"
                },
                {
                    "type": "File",
                    "id": "#bisulfite_qc.cwl/bam"
                },
                {
                    "type": "string",
                    "default": "bisulfite_QC",
                    "id": "#bisulfite_qc.cwl/output_dir"
                },
                {
                    "type": "string",
                    "id": "#bisulfite_qc.cwl/reference"
                },
                {
                    "type": "File",
                    "id": "#bisulfite_qc.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#bisulfite_qc.cwl/gather_to_sub_directory/gathered_directory",
                    "id": "#bisulfite_qc.cwl/QC_directory"
                }
            ],
            "steps": [
                {
                    "run": "#bisulfite_qc_conversion.cwl",
                    "in": [
                        {
                            "source": "#bisulfite_qc.cwl/QCannotation",
                            "id": "#bisulfite_qc.cwl/bisulfite_conversion/QCannotation"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/bam",
                            "id": "#bisulfite_qc.cwl/bisulfite_conversion/bam"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/reference",
                            "id": "#bisulfite_qc.cwl/bisulfite_conversion/reference"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/vcf",
                            "id": "#bisulfite_qc.cwl/bisulfite_conversion/vcf"
                        }
                    ],
                    "out": [
                        "#bisulfite_qc.cwl/bisulfite_conversion/base_convertion",
                        "#bisulfite_qc.cwl/bisulfite_conversion/read_convertion",
                        "#bisulfite_qc.cwl/bisulfite_conversion/cph_retention",
                        "#bisulfite_qc.cwl/bisulfite_conversion/cpg_retention"
                    ],
                    "id": "#bisulfite_qc.cwl/bisulfite_conversion"
                },
                {
                    "run": "#bisulfite_qc_coverage_stats.cwl",
                    "in": [
                        {
                            "source": "#bisulfite_qc.cwl/QCannotation",
                            "id": "#bisulfite_qc.cwl/coverage_stats/QCannotation"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/bam",
                            "id": "#bisulfite_qc.cwl/coverage_stats/bam"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/reference",
                            "id": "#bisulfite_qc.cwl/coverage_stats/reference"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/vcf",
                            "id": "#bisulfite_qc.cwl/coverage_stats/vcf"
                        }
                    ],
                    "out": [
                        "#bisulfite_qc.cwl/coverage_stats/bga_bed",
                        "#bisulfite_qc.cwl/coverage_stats/cov_dist",
                        "#bisulfite_qc.cwl/coverage_stats/bga_bed_dup",
                        "#bisulfite_qc.cwl/coverage_stats/dup_report",
                        "#bisulfite_qc.cwl/coverage_stats/cpg_bed",
                        "#bisulfite_qc.cwl/coverage_stats/cov_dist_cpg",
                        "#bisulfite_qc.cwl/coverage_stats/cpg_dist"
                    ],
                    "id": "#bisulfite_qc.cwl/coverage_stats"
                },
                {
                    "run": "#bisulfite_qc_cpg_retention_distribution.cwl",
                    "in": [
                        {
                            "source": "#bisulfite_qc.cwl/QCannotation",
                            "id": "#bisulfite_qc.cwl/cpg_retention_distribution/QCannotation"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/bam",
                            "id": "#bisulfite_qc.cwl/cpg_retention_distribution/bam"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/reference",
                            "id": "#bisulfite_qc.cwl/cpg_retention_distribution/reference"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/vcf",
                            "id": "#bisulfite_qc.cwl/cpg_retention_distribution/vcf"
                        }
                    ],
                    "out": [
                        "#bisulfite_qc.cwl/cpg_retention_distribution/cpg_retention_dist"
                    ],
                    "id": "#bisulfite_qc.cwl/cpg_retention_distribution"
                },
                {
                    "run": "#gather_to_sub_directory.cwl",
                    "in": [
                        {
                            "source": [
                                "#bisulfite_qc.cwl/bisulfite_conversion/base_convertion",
                                "#bisulfite_qc.cwl/bisulfite_conversion/read_convertion",
                                "#bisulfite_qc.cwl/bisulfite_conversion/cph_retention",
                                "#bisulfite_qc.cwl/bisulfite_conversion/cpg_retention",
                                "#bisulfite_qc.cwl/mapping_summary/strand_table",
                                "#bisulfite_qc.cwl/mapping_summary/mapping_quality",
                                "#bisulfite_qc.cwl/cpg_retention_distribution/cpg_retention_dist",
                                "#bisulfite_qc.cwl/coverage_stats/bga_bed",
                                "#bisulfite_qc.cwl/coverage_stats/cov_dist",
                                "#bisulfite_qc.cwl/coverage_stats/bga_bed_dup",
                                "#bisulfite_qc.cwl/coverage_stats/dup_report",
                                "#bisulfite_qc.cwl/coverage_stats/cpg_bed",
                                "#bisulfite_qc.cwl/coverage_stats/cov_dist_cpg",
                                "#bisulfite_qc.cwl/coverage_stats/cpg_dist"
                            ],
                            "id": "#bisulfite_qc.cwl/gather_to_sub_directory/files"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/output_dir",
                            "id": "#bisulfite_qc.cwl/gather_to_sub_directory/outdir"
                        }
                    ],
                    "out": [
                        "#bisulfite_qc.cwl/gather_to_sub_directory/gathered_directory"
                    ],
                    "id": "#bisulfite_qc.cwl/gather_to_sub_directory"
                },
                {
                    "run": "#bisulfite_qc_mapping_summary.cwl",
                    "in": [
                        {
                            "source": "#bisulfite_qc.cwl/QCannotation",
                            "id": "#bisulfite_qc.cwl/mapping_summary/QCannotation"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/bam",
                            "id": "#bisulfite_qc.cwl/mapping_summary/bam"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/reference",
                            "id": "#bisulfite_qc.cwl/mapping_summary/reference"
                        },
                        {
                            "source": "#bisulfite_qc.cwl/vcf",
                            "id": "#bisulfite_qc.cwl/mapping_summary/vcf"
                        }
                    ],
                    "out": [
                        "#bisulfite_qc.cwl/mapping_summary/strand_table",
                        "#bisulfite_qc.cwl/mapping_summary/mapping_quality"
                    ],
                    "id": "#bisulfite_qc.cwl/mapping_summary"
                }
            ],
            "id": "#bisulfite_qc.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "BAM to CRAM conversion",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-C"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.bam.nameroot).cram",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_to_cram.cwl/bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#bam_to_cram.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_to_cram.cwl/cram",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).cram"
                    }
                }
            ],
            "id": "#bam_to_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Picard: BAM to FASTQ",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/picard/picard.jar",
                "SamToFastq",
                "VALIDATION_STRINGENCY=SILENT"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/rnaseq:1.0.0"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "F=$(runtime.outdir)/read1.fastq"
                },
                {
                    "valueFrom": "F2=$(runtime.outdir)/read2.fastq"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I=",
                        "separate": false,
                        "position": 1
                    },
                    "id": "#bam_to_fastq.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "read1.fastq"
                    },
                    "id": "#bam_to_fastq.cwl/fastq1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "read2.fastq"
                    },
                    "id": "#bam_to_fastq.cwl/fastq2"
                }
            ],
            "id": "#bam_to_fastq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bedGraph to bigwig conversion",
            "baseCommand": [
                "/bin/bash",
                "bed2bigwig.sh"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bisulfite:v1.4"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "bed2bigwig.sh",
                            "entry": "set -eou pipefail\n    \n    for FILE in ${@:2}\n    do\n        filename=`basename $FILE .bedgraph`\n        /usr/bin/bedGraphToBigWig $FILE $1 $filename.bw\n    done\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bedgraph_to_bigwig.cwl/methylation_bedgraph"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bedgraph_to_bigwig.cwl/reference_sizes"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.bw"
                    },
                    "id": "#bedgraph_to_bigwig.cwl/methylation_bigwig"
                }
            ],
            "id": "#bedgraph_to_bigwig.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit: align",
            "baseCommand": [
                "/bin/bash",
                "biscuit_align.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "coresMin": 12
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "biscuit_align.sh",
                            "entry": "set -eou pipefail\n\ncores=$1\noutdir=\"$2\"\nread_group_id=\"$3\"\nreference_index=\"$4\"\nfastq1=\"$5\"\nfastq2=\"$6\"\n\n/usr/bin/biscuit align -t $cores -M -R \"$read_group_id\" \"$reference_index\" \"$fastq1\" \"$fastq2\" | /usr/bin/sambamba view -S -f bam -l 0 /dev/stdin | /usr/bin/sambamba sort -t $cores -m 8G -o \"$outdir/aligned.bam\" /dev/stdin\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": -9
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -8
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#biscuit_align.cwl/fastq1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#biscuit_align.cwl/fastq2"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#biscuit_align.cwl/read_group_id"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -3
                    },
                    "id": "#biscuit_align.cwl/reference_index"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "aligned.bam"
                    },
                    "id": "#biscuit_align.cwl/aligned_bam"
                }
            ],
            "id": "#biscuit_align.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit dedup",
            "baseCommand": [
                "/bin/bash",
                "biscuit_markdup.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 24000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "biscuit_markdup.sh",
                            "entry": "set -eou pipefail\n\ncores=$1\noutdir=\"$2\"\nbam=\"$3\"\n\n/usr/bin/biscuit markdup \"$bam\" /dev/stdout | /usr/bin/sambamba sort -t $cores -m 15G -o \"$outdir/markdup.bam\" /dev/stdin\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": -3
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -2
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#biscuit_markdup.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "markdup.bam"
                    },
                    "id": "#biscuit_markdup.cwl/markdup_bam"
                }
            ],
            "id": "#biscuit_markdup.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit pileup",
            "baseCommand": [
                "/bin/bash",
                "helper.sh"
            ],
            "stdout": "pileup.vcf.gz",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 48000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "helper.sh",
                            "entry": "set -eo pipefail\n\ncores=$1\nreference_fasta=\"$2\"\nbam=\"$3\"\n\n/usr/bin/biscuit pileup -q $cores -w pileup_stats.txt  \"$reference_fasta\" \"$bam\" | /opt/htslib/bin/bgzip\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": -9
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#biscuit_pileup.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#biscuit_pileup.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#biscuit_pileup.cwl/vcf",
                    "outputBinding": {
                        "glob": "pileup.vcf.gz"
                    }
                }
            ],
            "id": "#biscuit_pileup.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit QC: Bisulfite conversion rate.",
            "baseCommand": [
                "/bin/bash",
                "/opt/biscuit/scripts/Bisulfite_QC_bisulfiteconversion.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 20000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#bisulfite_qc_conversion.cwl/QCannotation"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bisulfite_qc_conversion.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bisulfite_qc_conversion.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bisulfite_qc_conversion.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "totalBaseConversionRate.txt"
                    },
                    "id": "#bisulfite_qc_conversion.cwl/base_convertion"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "CpGRetentionByReadPos.txt"
                    },
                    "id": "#bisulfite_qc_conversion.cwl/cpg_retention"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "CpHRetentionByReadPos.txt"
                    },
                    "id": "#bisulfite_qc_conversion.cwl/cph_retention"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "totalReadConversionRate.txt"
                    },
                    "id": "#bisulfite_qc_conversion.cwl/read_convertion"
                }
            ],
            "id": "#bisulfite_qc_conversion.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit QC: Bisulfite conversion rate.",
            "baseCommand": [
                "/bin/bash",
                "/opt/biscuit/scripts/Bisulfite_QC_Coveragestats.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 20000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/QCannotation"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bga.bed"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/bga_bed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bga_dup.bed"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/bga_bed_dup"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "covdist_table.txt"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/cov_dist"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "covdist_cpg_table.txt"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/cov_dist_cpg"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cpg.bed"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/cpg_bed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cpg_dist_table.txt"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/cpg_dist"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "dup_report.txt"
                    },
                    "id": "#bisulfite_qc_coverage_stats.cwl/dup_report"
                }
            ],
            "id": "#bisulfite_qc_coverage_stats.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit QC: CpG Retention Distribution",
            "baseCommand": [
                "/bin/bash",
                "/opt/biscuit/scripts/Bisulfite_QC_CpGretentiondistribution.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/QCannotation"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "CpGRetentionDist.txt"
                    },
                    "id": "#bisulfite_qc_cpg_retention_distribution.cwl/cpg_retention_dist"
                }
            ],
            "id": "#bisulfite_qc_cpg_retention_distribution.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit QC: Bisulfite conversion rate.",
            "baseCommand": [
                "/bin/bash",
                "/opt/biscuit/scripts/Bisulfite_QC_mappingsummary.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/QCannotation"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mapq_table.txt"
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/mapping_quality"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "strand_table.txt"
                    },
                    "id": "#bisulfite_qc_mapping_summary.cwl/strand_table"
                }
            ],
            "id": "#bisulfite_qc_mapping_summary.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "convert a biscuit pileup vcf to a bed and bedgraph file, via a wrapper script",
            "baseCommand": [
                "/bin/bash",
                "bsvcf2bed.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 2
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "bsvcf2bed.sh",
                            "entry": "set -eou pipefail\n\nif [[ $3 == \"false\" ]]\nthen\n    #Creates a gzipped bed and a bedgraph that leaves out MT, random, GL contigs, etc\n    /usr/bin/biscuit vcf2bed -t cg -k 1 -e $1 | /usr/bin/biscuit mergecg $2 /dev/stdin -k 2 |  tee >(/bin/gzip >cpgs.bed.gz) | cut -f 1-4 | sort -k1,1 -k2,2n -S 12G | /usr/bin/perl -ne 'print $_ if $_ =~ /^(chr)?[1-9]?[0-9|X|Y]\\s/' >cpgs.bedgraph\nelse\n    /usr/bin/biscuit vcf2bed -t cg -k 1 -e $1 | /usr/bin/biscuit mergecg $2 /dev/stdin -k 2 |  tee >(/bin/gzip >cpgs.bed.gz) | cut -f 1-4 | sort -k1,1 -k2,2n -S 12G | /usr/bin/perl -ne 'print $_ if $_ =~ /^(chr)?[1-9]?[0-9|X|Y]\\s/' >cpgs.bedgraph\n    /usr/bin/biscuit vcf2bed -t ch -k 1 -e $1 | awk '$6 == \"CA\"' | tee >(/bin/gzip >cpas.bed.gz) | cut -f 1-3,8 | sort -k1,1 -k2,2n -S 12G | /usr/bin/perl -ne 'print $_ if $_ =~ /^(chr)?[1-9]?[0-9|X|Y]\\s/' >cpas.bedgraph\n    /usr/bin/biscuit vcf2bed -t ch -k 1 -e $1 | awk '$6 == \"CT\"' | tee >(/bin/gzip >cpts.bed.gz) | cut -f 1-3,8 | sort -k1,1 -k2,2n -S 12G | /usr/bin/perl -ne 'print $_ if $_ =~ /^(chr)?[1-9]?[0-9|X|Y]\\s/' >cpts.bedgraph\n    /usr/bin/biscuit vcf2bed -t ch -k 1 -e $1 | awk '$6 == \"CC\"' | tee >(/bin/gzip >cpcs.bed.gz) | cut -f 1-3,8 | sort -k1,1 -k2,2n -S 12G | /usr/bin/perl -ne 'print $_ if $_ =~ /^(chr)?[1-9]?[0-9|X|Y]\\s/' >cpcs.bedgraph\nfi\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#bisulfite_vcf2bed.cwl/assay_non_cpg_sites/true",
                            "#bisulfite_vcf2bed.cwl/assay_non_cpg_sites/false"
                        ]
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bisulfite_vcf2bed.cwl/assay_non_cpg_sites"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bisulfite_vcf2bed.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bisulfite_vcf2bed.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.bed.gz"
                    },
                    "id": "#bisulfite_vcf2bed.cwl/methylation_bed"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.bedgraph"
                    },
                    "id": "#bisulfite_vcf2bed.cwl/methylation_bedgraph"
                }
            ],
            "id": "#bisulfite_vcf2bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "directory_gatherer.sh"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:xenial"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "directory_gatherer.sh",
                            "entry": "set -eou pipefail\n\noutdir=\"$1\"\nfiles=\"${@:2}\"\nmkdir $outdir\nchmod -R 777 $outdir\ncp -t $outdir $files\n\nexit 0\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#gather_to_sub_directory.cwl/files"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#gather_to_sub_directory.cwl/outdir"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.outdir)"
                    },
                    "id": "#gather_to_sub_directory.cwl/gathered_directory"
                }
            ],
            "id": "#gather_to_sub_directory.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.bam; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index cram",
            "arguments": [
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                "$(runtime.outdir)/$(inputs.cram.basename).crai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.cram.basename).crai",
                "$(runtime.outdir)/$(inputs.cram.nameroot).crai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.cram; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_cram.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename)"
                    },
                    "id": "#index_cram.cwl/indexed_cram"
                }
            ],
            "id": "#index_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Sambamba: merge",
            "baseCommand": [
                "/usr/bin/sambamba_merge"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8.2"
                }
            ],
            "arguments": [
                "$(runtime.cores)",
                "$(runtime.outdir)/merged.bam"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge_bams.cwl/bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "merged.bam"
                    },
                    "id": "#merge_bams.cwl/merged_bam"
                }
            ],
            "id": "#merge_bams.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Trim FASTQ (flexbar)",
            "baseCommand": [
                "/opt/flexbar/flexbar"
            ],
            "arguments": [
                "--target",
                {
                    "valueFrom": "$(runtime.outdir)/trimmed_read"
                },
                "--threads",
                {
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 25000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bisulfite:v1.4"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--adapter-min-overlap",
                        "position": 3
                    },
                    "id": "#trim_fastq.cwl/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--adapter-trim-end",
                        "position": 2
                    },
                    "id": "#trim_fastq.cwl/adapter_trim_end"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--adapters",
                        "position": 1
                    },
                    "id": "#trim_fastq.cwl/adapters"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--max-uncalled",
                        "position": 5
                    },
                    "id": "#trim_fastq.cwl/max_uncalled"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--min-read-length",
                        "position": 6
                    },
                    "id": "#trim_fastq.cwl/min_readlength"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads",
                        "position": 7
                    },
                    "id": "#trim_fastq.cwl/reads1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads2",
                        "position": 8
                    },
                    "id": "#trim_fastq.cwl/reads2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trimmed_read_1.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastq1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trimmed_read_2.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastq2"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "trimmed_read_*.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastqs"
                }
            ],
            "id": "#trim_fastq.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
